Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TwoSat ¶
type TwoSat struct {
// contains filtered or unexported fields
}
TwoSat defines n, answer and scc
func (*TwoSat) Answer ¶
Answer returns a truth assignment that satisfies all clauses of the last call of satisfiable
func (*TwoSat) Satisfiable ¶
Satisfiable returns True if there is a truth assignment that satisfies all clauses
Click to show internal directories.
Click to hide internal directories.